<?php
/* utf8-marker = äöüß */

/*
 * Swiper_XH
 * @copyright   Frank Seidel, Olaf Penschke
 * @author      Frank Seidel    frase
 * @author      Olaf Penschke   olape
 * @version     1.0 RC1 (08.04.2020)
 * @link        http://fhseidel.de/ http://olaf.penschke.net/

 * @license     http://www.gnu.org/licenses/gpl-3.0.en.html GNU GPLv3
 
 * Swiper (MIT Licensed) https://swiperjs.com

================================================================================
*/

// return all hidden subpages only from the next sitelevel
function op_SW_FindHiddenSubpages() {

global $s, $l, $h, $xh_publisher;

    // if login and $s < 0, i.e. setting or plugins
    if(XH_ADM && $s < 0) {return false;}

    $hisupa_array = array();
    for($count = 0;;) {
        $count++;
        if($l[$s + $count] == $l[$s]) break;
        if($l[$s + $count] < $l[$s] + 2) {
            if($xh_publisher->isHidden($s + $count)) {
                $hisupa_array[] = $h[$s + $count];
            }
        }
    }

    return $hisupa_array;
}

// return an array of pages from $pages
function op_SW_pageSeries($pages) {

    global $h, $s;

    $pages = trim($pages, '|');
    $pageSeries_array = explode('|', $pages);

    return $pageSeries_array;
}

// return swipe-pages
function op_SW_MakeSwipePages($sw_mode, $pages) {

    if($sw_mode == 'auto') {
        $tmpin = op_SW_FindHiddenSubpages();
    }
    if($sw_mode == 'pageSeries') {
        $tmpin = op_SW_pageSeries($pages);
    }
    // if no pages found
    if($tmpin == '') {
        return XH_message('fail', 'no pages selected');
    }

    $swipepages = '';
    $slidecount = 0;

    foreach($tmpin as $tmp) {
        $slidecount++;
        $slidearray = op_SW_Newsbox($tmp);

        $swipepages .= '<div class="swiper-slide slide' . $slidecount . '"';
        // start inline style
        if(((isset($slidearray[1])) && (trim($slidearray[1]) != ''))
        || ((isset($slidearray[2])) && (trim($slidearray[2]) != ''))) {
            // inline style
            $swipepages_tmp = '';
            $swipepages .= ' style="';
        }
        // inline style, background-color for slide from pagedata
        // hex, hex with alpha, rgb, rgba, hsl, hsla
        if(((isset($slidearray[1])) && (trim($slidearray[1]) != '')) 
        && ((substr($slidearray[1], 0, 1) == '#')
        || (substr($slidearray[1], 0, 3) == 'rgb')
        || (substr($slidearray[1], 0, 3) == 'hsl'))) {
            $swipepages_tmp .= 'background-color: ' . $slidearray[1] . ';';
        }
        // inline style, background-image for slide from pagedata
        if((isset($slidearray[2])) && (trim($slidearray[2]) != '')) {
            $swipepages_tmp .= ' background-image: url(\''
                            . op_SW_SetPath() . 'images/'
                            . $slidearray[2] . '\');';
        }
        // end inline style
        if(((isset($slidearray[1])) && (trim($slidearray[1]) != ''))
        || ((isset($slidearray[2])) && (trim($slidearray[2]) != ''))) {
            $swipepages_tmp = ltrim($swipepages_tmp);
            $swipepages .= $swipepages_tmp;
            $swipepages .= '"';
        }
        // end div
        $swipepages .= '>'. "\n";
        // if is return not empty
        if($slidearray[0] != '') {
            $swipepages .= $slidearray[0] . "\n";
        } else {
            $swipepages .= XH_message('fail', 'page not found');
        }
        $swipepages .= '</div>'. "\n";
    }

    return $swipepages;
}

// return path were the set-files are stored
function op_SW_SetPath() {

global $pth;

    $dirtmp = $pth['folder']['base']
            . substr($pth['folder']['userfiles'], 2)
            . 'swiper-sets/';

    return $dirtmp;
}

// return the include swiper.min.css only 1x
function op_SW_swiper_min_css() {

global $pth, $hjs;

    if(strpos($hjs, 'swiper.min.css') === false) {
        $hjstmp = '<link rel="stylesheet" href="' 
                . $pth['folder']['plugins'] 
                . 'swiper/css/swiper.min.css" type="text/css">' 
                . "\n";
        return $hjstmp;
    }

    return false;
}

// a copy of function newsbox() extendet with reading pagedata
// and not the Swiper page itself
function op_SW_Newsbox($heading)
{
    global $c, $cl, $h, $s, $edit, $pd_router;

    $nb_array = array();


    for ($i = 0; $i < $cl; $i++) {
        // if login and $s < 0, i.e. setting or plugins
        if(XH_ADM && $s < 0) {return false;}
        // not the Swiper page itself ($h[$i] != $h[$s])
        // and heading found ($h[$i] == $heading)
        if (($h[$i] != $h[$s]) && ($h[$i] == $heading)) {
            $pattern = '/.*?<!--XH_ml[1-9]:.*?-->/isu';
            $body = preg_replace($pattern, "", $c[$i]);
            $pattern = '/#CMSimple (.*?)#/is';
            $nb_array[] .= XH_ADM && $edit
                         ? $body
                         : preg_replace($pattern, '', evaluate_scripting($body, false));
            // background-color
            $pd_array = $pd_router->find_page($i);
            $pd_bc_tmp = trim($pd_array['sw_slider_bgcolor']);
            $nb_array[] .= $pd_bc_tmp;
            // background-image
            $pd_bi_tmp = trim($pd_array['sw_slider_bgimg']);
            $nb_array[] .= $pd_bi_tmp;
            /*
            echo "<pre>";
            print_r($pd_array);
            echo "</pre>";
            */
            return $nb_array;
        }
    }
    return false;
}

//return a list of images for admin
function op_SW_ImgDropField($selection = '') {

    global $pth;

    $sw_images = '';
    $sw_allimages = scandir(op_SW_SetPath() . 'images/');

    foreach($sw_allimages as $sw_img_tmp) {
        if(($sw_img_tmp != '.') 
        && ($sw_img_tmp != '..')
        && ($sw_img_tmp != '.htaccess')) {
            $sw_img_info = pathinfo(op_SW_SetPath()
                         . 'images/' 
                         . $sw_img_tmp);
            if(($sw_img_info['extension'] == 'png') 
            || ($sw_img_info['extension'] == 'jpg') 
            || ($sw_img_info['extension'] == 'gif')
            || ($sw_img_info['extension'] == 'svg')) {
                $sw_images .= $sw_img_tmp . ',';
            }
        }
    };
    
    if($selection == 'enum') {
        $sw_images = rtrim($sw_images, ',');
    } else if($selection == 'option') {
        $sw_images = rtrim($sw_images, ',');
        $sw_images = '<option>'
                    . str_replace(',', '</option><option>', $sw_images)
                    . '</option>';
    }
    return $sw_images;
}

// return data list for form field for admin
function op_SW_DatatList($sw_data = '', $sw_id = '') {

    $sw_data_list = '';
    $sw_data_list_count = 0;

    $sw_tmp_list = preg_split('/\r\n|\r|\n/', $sw_data);
    foreach ($sw_tmp_list as $sw_tmp_data) {
        if($sw_tmp_data != '') {
            $sw_data_list .= '<option value="' . $sw_tmp_data . '"></option>';
            $sw_data_list_count++;
        }
    }
    if($sw_data_list_count > 1) {
        $sw_data_list = '<datalist id="' . $sw_id . '">' 
                      . $sw_data_list 
                      . '</datalist>';
    }
    return $sw_data_list;
}

//return a list of zip-files for admin
function op_SW_SetZip() {

    global $plugin_tx;

    $sw_zips = '';
    $sw_allzips = scandir(op_SW_SetPath());
    $sw_link_title = $plugin_tx['swiper']['backend_sets_link-title'];
    $sw_sets_exist = $plugin_tx['swiper']['backend_sets_exist'];
    $sw_sets_nozips = $plugin_tx['swiper']['backend_sets_nozips'];

    foreach($sw_allzips as $sw_zip_tmp) {
        if(($sw_zip_tmp != '.')
        && ($sw_zip_tmp != '..')
        && ($sw_zip_tmp != '.htaccess')) {
            $sw_zip_info = pathinfo(op_SW_SetPath() . $sw_zip_tmp);
            if(isset($sw_zip_info['extension'])
            && $sw_zip_info['extension'] == 'zip') {
                $op_zip_name = $sw_zip_info['filename'];
                $sw_zips .= '<li'
                         . ((is_dir(op_SW_SetPath() . $op_zip_name) === true)
                            ? ' title="'
                                . $sw_sets_exist
                                . '" class="swiper_zip_exist"'
                            : '')
                          . '><a title="' 
                         . $sw_link_title 
                         . '" href="?&swiper&admin=plugin_sets&unzip=' 
                         . $sw_zip_tmp 
                         . '">' . $sw_zip_tmp
                         . '</a>'
                         . '</li>';
            }
        }
    }
    if($sw_zips == '') {
        $sw_zips = '<p>' . $sw_sets_nozips . '</p>';
        return $sw_zips;
    }
    $sw_zips = '<ul>' . $sw_zips . '</ul>';
    return $sw_zips;
}

//return a list of set-folder for admin
function op_SW_SetFolder() {

    global $plugin_tx;

    $sw_dirs = '';
    $sw_alldirs = scandir(op_SW_SetPath());
    $sw_sets_readme = $plugin_tx['swiper']['backend_sets_readme'];
    $sw_sets_nofolders = $plugin_tx['swiper']['backend_sets_nofolders'];

    foreach($sw_alldirs as $sw_dir_tmp) {
        if(($sw_dir_tmp != '.')
        && ($sw_dir_tmp != '..')
        && ($sw_dir_tmp != 'images')) {
            if(is_dir(op_SW_SetPath() . $sw_dir_tmp) !== false) {
                $sw_dirs .= '<li>'
                         //. $sw_dir_tmp
                         . (is_readable(op_SW_SetPath() . $sw_dir_tmp . '/readme.txt')
                            ? '<a title= "'
                                . $sw_sets_readme
                                . '" target="_blank" href="'
                                . op_SW_SetPath()
                                . $sw_dir_tmp
                                . '/readme.txt">'
                                . $sw_dir_tmp
                                . '</a>'
                            : $sw_dir_tmp)
                         . '</li>';
            }
        }
    }
    if($sw_dirs == '') {
        $sw_dirs = '<p>' . $sw_sets_nofolders . '</p>';
        return $sw_dirs;
    }
    $sw_dirs = '<ul>' . $sw_dirs . '</ul>';
    return $sw_dirs;
}

// unzip sets for admin
function op_SW_UnZip($zip = '') {

    $op_set_foldername = substr($zip, 0, -4);
    mkdir(op_SW_SetPath() . $op_set_foldername, 0777);
    chmod(op_SW_SetPath() . $op_set_foldername, 0777);

    $op_zip = new ZipArchive;
    if($op_zip->open(op_SW_SetPath() . $zip) !== TRUE) {
        Return false;
    } else {
        $op_zip->extractTo(op_SW_SetPath() . $op_set_foldername);
        $op_zip->close();
        // chmod
        $op_chmod_path = op_SW_SetPath() . $op_set_foldername;
        op_SW_chmod($op_chmod_path);
    }
}

// chmod sets after unzip (recursive)
function op_SW_chmod($op_chmod_path = '') {

    $sw_setfiles = scandir($op_chmod_path);

    foreach($sw_setfiles as $sw_setfiles_tmp) {
        if(($sw_setfiles_tmp != '.')
        && ($sw_setfiles_tmp != '..')) {
            if(is_dir($op_chmod_path . '/' . $sw_setfiles_tmp) !== false) {
                chmod($op_chmod_path . '/' . $sw_setfiles_tmp, 0777);
                op_SW_chmod($op_chmod_path. '/' . $sw_setfiles_tmp);
            } else {
                chmod($op_chmod_path . '/' . $sw_setfiles_tmp, 0666);
            }
        }
    }
}